@@ -700,3 +700,8 @@ def test_skip_imagecoord():
 def test_Sections_block():
     assert_array_equal(Morphology(DATA_DIR / 'sections-block.asc').points,
                        Morphology(DATA_DIR / 'simple.asc').points)
+
+def test_marker_with_string():
+    m = Morphology(DATA_DIR / 'marker-with-string.asc')
+    assert_array_equal(m.markers[0].points, np.array([[  -0.97    , -141.169998,   84.769997]],
+                                                     dtype=np.float32))
